pub struct KeyStore { /* private fields */ }Expand description
Store for OpenPGP private keys.
Implementations
Sourceimpl KeyStore
impl KeyStore
Sourcepub fn default_location() -> Result<PathBuf, PgpError>
pub fn default_location() -> Result<PathBuf, PgpError>
Returns the default path for the key store.
Sourcepub async fn open(path: Option<&Path>) -> Result<Self, PgpError>
pub async fn open(path: Option<&Path>) -> Result<Self, PgpError>
Opens a key store from disk.
If path is not None, the specified location is used. Otherwise,
if the SETT_KEYSTORE environment variable is set, its value is used.
It defaults to the data directory defined by the sequoia_directories
crate.
Sourcepub async fn open_ephemeral() -> Result<Self, PgpError>
pub async fn open_ephemeral() -> Result<Self, PgpError>
Opens an ephemeral key store.
The key store is created in a temporary directory, which is deleted when the key store is dropped.
Sourcepub async fn import(&mut self, cert: Cert) -> Result<Vec<Key>, PgpError>
pub async fn import(&mut self, cert: Cert) -> Result<Vec<Key>, PgpError>
Imports secret keys present in a TSK (Transferable Secret Key).
Ignores any keys without secret material.
Sourcepub async fn list(&mut self) -> Result<Vec<Key>, PgpError>
pub async fn list(&mut self) -> Result<Vec<Key>, PgpError>
List all keys from all backends of the store.
Sourcepub async fn find_key(
&mut self,
fingerprint: Fingerprint,
) -> Result<Vec<Key>, PgpError>
pub async fn find_key( &mut self, fingerprint: Fingerprint, ) -> Result<Vec<Key>, PgpError>
Find a key by its fingerprint.
If the key is found on multiple devices, it returns multiple keys.
Sourcepub async fn delete_key(
&mut self,
fingerprint: Fingerprint,
) -> Result<(), PgpError>
pub async fn delete_key( &mut self, fingerprint: Fingerprint, ) -> Result<(), PgpError>
Delete key from the key store.