pub enum Either<A, B> {
Either(A),
Or(B),
}Expand description
Intermediate container for 2 variants.
Used e.g. to propagate 2 error variants to a higher level error enum while at the same time hide the rest of the higher level variants to the implementation using Either.
Variants